# `ase-hdf5` - simple reading and writing of list[ase.Atoms] objects

<div align="center">

[![GitHub](https://img.shields.io/github/license/tcnicholas/ase-hd5f)](LICENCE.md)
[![](https://github.com/tcnicholas/ase-hd5f/actions/workflows/tests.yaml/badge.svg?branch=main)](https://github.com/tcnicholas/ase-hd5f/actions/workflows/tests.yaml)
[![codecov](https://codecov.io/gh/tcnicholas/ase-hd5f/branch/master/graph/badge.svg?token=VGSFM0GWF1)](https://codecov.io/gh/tcnicholas/ase-hdf5)
</div>